# Microsoft Applications Modeling Best Practices
### On this page
  * [Microsoft Azure (IaaS)](https://help.sap.com/docs/leanix/ea/microsoft-applications-modeling-best-practices#microsoft-azure-\(iaas\))
  * [Microsoft Dynamics](https://help.sap.com/docs/leanix/ea/microsoft-applications-modeling-best-practices#microsoft-dynamics)
  * [Microsoft Office 365](https://help.sap.com/docs/leanix/ea/microsoft-applications-modeling-best-practices#microsoft-office-365)


This modeling guide offers best practices for modeling Microsoft solutions like Microsoft Azure, Microsoft Dynamics, and Microsoft Office 365.
